==> taffybar-4.0.3-193-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-4rfGfcjGmhL6X9UYuNyDqd
key:                    taffybar-4.0.3-4rfGfcjGmhL6X9UYuNyDqd
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    a13246d6ef208d17d7acb3fcd8c83113
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-4rfGfcjGmhL6X9UYuNyDqd
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype bz2
    png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-FT6SzQYxStQJ7fouUkFuoW
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB
    ansi-terminal-1.0.2-HjENL9BIUVI6RnTwgiyfuy base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-LSEd28HkJLcLIWho4Hpdv5 containers-0.6.7
    data-default-0.7.1.2-1WYBg9tpZep2i2jrc12PQs
    dbus-1.3.3-D3wVT4xEiNqCxwUDcCuN7M
    dbus-hslogger-0.1.0.1-FfbLFwXmDitHL9QnOawSxS directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.3-FOAbNcCNUjIJuj6gguErdR
    enclosed-exceptions-1.0.3-2bSaxbS2Cf77u0zaWhpcsN filepath-1.4.2.2
    gi-cairo-connector-0.1.1-24AKobtRo3q8DF1yuJ7zPL
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    gi-gdk-3.0.28-CidyhHwFxm9Fem99mC2wza
    gi-gdkpixbuf-2.0.32-7Ax8QTsimUF6n6wxJGUgNr
    gi-gdkx11-3.0.13-DrSexieZ6gL78SDb1spafK
    gi-glib-2.0.30-Jq6IQxafM0H9TpFBzPjoyC
    gi-gtk-3.0.39-737xXs9XZ6Z7gNtK5bCt4e
    gi-gtk-hs-0.3.17-7pHeThwXX5YF3fHtDTpP1c
    gi-pango-1.0.29-IgQRKHrrBCZ1H3Lu0BQtpj
    gtk-sni-tray-0.1.8.1-6Xi5hWTvSLEFmXcZrWY1D6
    gtk-strut-0.1.3.2-1uwKUh9a1HV53nXxJTYDNI
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.2.0-3OfRhND7Zsp4rzF9j06Ouq
    http-client-0.7.19-2IAKaL0RajRLDWsZpaLmo9
    http-client-tls-0.3.6.4-2Fy9IJdNZPjACQ4RZSV8Nh
    http-conduit-2.3.9.1-IBKu1TrmJP6Kq88yCkjWcg
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-3NYlWmvK5NXAlxNW2aDsvC
    scotty-0.22-7xgp5kR9WzAEYxSgQhcDCH
    split-0.2.5-42FGdeEiiUOLLQR1FNYPlK
    status-notifier-item-0.3.1.0-1rENA3WRXN730zSprdvz60 stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-F8Zp4X8lqfmCf9yHmma1QF unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-6Vx9Dt4zgKF374lJSUMK06
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-1rjMFd2yfGy4iZNQYqSjXt

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> taffybar-4.0.3-194-x86_64.pkg.tar.zst: usr/share/haskell/register/taffybar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.0.3
visibility:             public
id:                     taffybar-4.0.3-I0LCPqz8xjG9R1NIendGv5
key:                    taffybar-4.0.3-I0LCPqz8xjG9R1NIendGv5
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    3676fd7be70c91f677af5b637a2786c9
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs:           /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/taffybar-4.0.3
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.0.3-I0LCPqz8xjG9R1NIendGv5
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype bz2
    png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-FT6SzQYxStQJ7fouUkFuoW
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig
    ansi-terminal-1.0.2-HjENL9BIUVI6RnTwgiyfuy base-4.17.2.1
    broadcast-chan-0.2.1.2-EL2bp18GDj1Y8ziKOtHVF bytestring-0.11.5.3
    conduit-1.3.6.1-3M1B5TjJPZk646ipFSI00d containers-0.6.7
    data-default-0.7.1.2-1WYBg9tpZep2i2jrc12PQs
    dbus-1.3.3-9Q6IvPTCjxP7SCESHDLnCj
    dbus-hslogger-0.1.0.1-BI9uAFLpdRTG3RrZpGTUtK directory-1.3.7.1
    dyre-0.9.2-6xsWj8cnPnO43rkWvoQDdD
    either-5.0.3-FOAbNcCNUjIJuj6gguErdR
    enclosed-exceptions-1.0.3-2bSaxbS2Cf77u0zaWhpcsN filepath-1.4.2.2
    gi-cairo-connector-0.1.1-1GJxIHGtuY346vNPVdmdXL
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    gi-gdk-3.0.28-92taqXAS2bcAwgWZDToUdg
    gi-gdkpixbuf-2.0.32-CJz8oAksauRKvIhUMzVUDB
    gi-gdkx11-3.0.13-3pVQQFe3xM2Ao8y4cBjWyJ
    gi-glib-2.0.30-LLSLAubMSZv17b4uDW7pRT
    gi-gtk-3.0.39-Dx07AXhOk9L9vFkrpRKJgD
    gi-gtk-hs-0.3.17-J12wIShLjd0IF3HRkGpaMs
    gi-pango-1.0.29-Agx58yhzcgA8b8q2MPf9qX
    gtk-sni-tray-0.1.8.1-FcWk0RqkicEKpUghMfoTiV
    gtk-strut-0.1.3.2-8kRAq7J1Q8cHSGwP2lFhCY
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.2.0-3OfRhND7Zsp4rzF9j06Ouq
    http-client-0.7.19-2IAKaL0RajRLDWsZpaLmo9
    http-client-tls-0.3.6.4-1BDRKQL1P8oJwrUsm96xXK
    http-conduit-2.3.9.1-2oN63nNuS8WGGNMCJvNhJ6
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz parsec-3.1.16.1
    process-1.6.18.0 rate-limit-1.4.3-BthbfOgtEPJEcM0huInRc0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8
    safe-0.3.21-3NYlWmvK5NXAlxNW2aDsvC
    scotty-0.22-Llv834tGefCFkHOVyxSQ8j
    split-0.2.5-42FGdeEiiUOLLQR1FNYPlK
    status-notifier-item-0.3.1.0-GmWztl5PjKZ1f02xPGhXQR stm-2.5.1.0
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    time-units-1.0.0-256CNFELv6i5YiHpTvd1at transformers-0.5.6.2
    tuple-0.3.0.2-F8Zp4X8lqfmCf9yHmma1QF unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
    xdg-desktop-entry-0.1.1.2-6Vx9Dt4zgKF374lJSUMK06
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG
    xml-helpers-1.0.0-3ETMafV7UcH4BpT6TqDnxm
    xmonad-0.18.0-5QFUMRQxEhIKNfhOyGFuiZ

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
